<?php
// Own namespace
namespace CoreFramework\Filter;

// Import framework stuff
use CoreFramework\Object\BaseFrameworkSystem;

/**
 * A general filter decorator for decorating filters with other filters
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2017 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
abstract class BaseFilterDecorator extends BaseFrameworkSystem implements Filterable {
	/**
	 * The decorated filter instance
	 */
	private $filterInstance = NULL;

	/**
	 * Protected constructor
	 *
	 * @param	$className	Name of the real class' name
	 * @return	void
	 */
	protected function __construct ($className) {
		// Call parent constructor
		parent::__construct($className);
	}

	/**
	 * Setter for the decorated filter instance
	 *
	 * @param	$filterInstance		An instance of a filter
	 * @return	void
	 */
	protected final function setFilterInstance (Filterable $filterInstance) {
		$this->filterInstance = $filterInstance;
	}

	/**
	 * Getter for the decorated filter instance
	 *
	 * @return	$filterInstance		An instance of a filter
	 */
	protected final function getFilterInstance () {
		return $this->filterInstance;
	}

	/**
	 * Execute the inner filter
	 *
	 * @param	$requestInstance	An instance of a request class
	 * @param	$responseInstance	An instance of a response class
	 * @return	void
	 */
	public final function execute (Requestable $requestInstance, Responseable $responseInstance) {
		$this->getFilterInstance()->execute($requestInstance, $responseInstance);
	}


	/**
	 * Do the execution of the filter
	 *
	 * @param	$requestInstance	An instance of a request class
	 * @param	$responseInstance	An instance of a response class
	 * @return	void
	 */
	abstract public function doExecute (Requestable $requestInstance, Responseable $responseInstance);

}
