<?php
// Own namespace
namespace CoreFramework\Compression;

// Import framework stuff
use CoreFramework\Generic\FrameworkInterface;

/**
 * An interface for compression classes
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2017 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
interface Compressor extends FrameworkInterface {
	/**
	 * A compression stream
	 *
	 * @param	$streamData		Mixed non-object stream data
	 * @return	$streamData		The compressed stream data
	 * @throws	InvalidObjectException	If the stream is an object
	 */
	function compressStream ($streamData);

	/**
	 * A decompression stream
	 *
	 * @param	$streamData		Mixed non-object stream data
	 * @return	$streamData		The decompressed stream data
	 * @throws	InvalidObjectException	If the stream is an object
	 */
	function decompressStream ($streamData);

	/**
	 * Getter for the file extension of this compressor
	 *
	 * @return	$string	The compressor's file extension
	 */
	function getCompressorExtension ();

}
